@@ -554,7 +554,7 @@ $$ language plpgsql;
                 """
         )
 
-    def get_worker_stats(self):
+    def get_worker_stats(self, limit=10):
         return self.dbc.query_many(
             """
             select
@@ -576,11 +576,16 @@ $$ language plpgsql;
             and
                 worker_id is not null
             and
-                now() - last_finished_at < interval '1 days'
+                now() - last_finished_at < interval '2 hours'
             group by
                 worker_id
+            order by
+                3 asc, 2 desc
+            limit
+                %(limit)s
             ;
-            """
+            """,
+            {"limit": (limit,)}
         )
 
     def get_job_times(self, statuses=["done"]):
